/*
 * Copyright 2000-2009 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.testFramework;

import com.intellij.openapi.util.Condition;
import com.intellij.util.containers.ContainerUtil;

import java.util.HashSet;
import java.util.Set;

public abstract class TreePrintCondition implements Condition<String> {

  public abstract static class SetBased extends TreePrintCondition {

    protected Set<String> mySet = new HashSet<>();

    public SetBased(String... elements) {
      ContainerUtil.addAll(mySet, elements);
    }
  }

  public static class Include extends SetBased {
    public Include(String... elements) {
      super(elements);
    }

    @Override
    public boolean value(String s) {
      return mySet.contains(s);
    }
  }

  public static class Exclude extends SetBased {
    public Exclude(String... elements) {
      super(elements);
    }

    @Override
    public boolean value(String s) {
      return !mySet.contains(s);
    }
  }

}
